@@ -1,6 +1,7 @@
+from datetime import datetime
 import requests
 
-from . import BaseUrl
+from . import BaseUrl, Unauthorised, InvalidParameter, NotFound
 
 
 class BaseApi:
@@ -29,11 +30,23 @@ class BaseApi:
         Makes request to Stalcraft API with Authorization and Content-Type header
         """
 
+        url = f"{self.base_url}/{method}"
+
         response = requests.get(
-            f"{self.base_url}/{method}",
+            url=url,
             headers=self.headers,
             params=params
         )
+
+        if response.status_code == 400:
+            raise InvalidParameter(f"One of parameters is invalid: '{url}' {params}")
+
+        if response.status_code == 401:
+            raise Unauthorised(f"Bad Token: '{self.part_of_token}'")
+
+        if response.status_code == 404:
+            raise NotFound(f"Not Found: '{url}' {params}")
+
         return response.json()
 
     def _offset_and_limit(self, offset: int, limit: int):
