@@ -1,4 +1,7 @@
+from datetime import datetime
+
 from . import BaseApi, BaseUrl, Order, Region, Sort
+from . import schemas
 
 
 class Auction(BaseApi):
@@ -11,7 +14,7 @@ class Auction(BaseApi):
         self.item_id = item_id
         self.region = region
 
-    def price_history(self, offset=0, limit=20):
+    def price_history(self, offset=0, limit=20, additional=False):
         """
         Returns history of prices for lots which were bought from auction for the given item.
         Prices are sorted in descending order by recorded time of purchase.
@@ -24,10 +27,12 @@ class Auction(BaseApi):
         self._offset_and_limit(offset, limit)
 
         method = f"{self.region.value}/auction/{self.item_id}/history"
-        params = {"offset": offset, "limit": limit}
-        return self._request(method, params)
+        params = {"offset": offset, "limit": limit, "additional": additional}
+        response = self._request(method, params)
 
-    def lots(self, offset=0, limit=20, sort=Sort.TIME_CREATED, order=Order.ASCENDING):
+        return schemas.Prices(response)
+
+    def lots(self, offset=0, limit=20, sort=Sort.TIME_CREATED, order=Order.ASCENDING, additional=False):
         """
         Returns list of currently active lots on the auction for the given item.
         Lots are sorted based on given parameter.
@@ -42,8 +47,10 @@ class Auction(BaseApi):
         self._offset_and_limit(offset, limit)
 
         method = f"{self.region.value}/auction/{self.item_id}/lots"
-        params = {"offset": offset, "limit": limit, "sort": sort.value, "order": order.value}
-        return self._request(method, params)
+        params = {"offset": offset, "limit": limit, "sort": sort.value, "order": order.value, "additional": additional}
+        response = self._request(method, params)
+
+        return schemas.Lots(response)
 
     def __repr__(self):
-        return f"<Clan> item='{self.item_id}' region='{self.region}'"
+        return f"<Auction> item='{self.item_id}' region='{self.region}'"
