@@ -1,4 +1,7 @@
-from . import BaseApi, BaseUrl, Region
+from datetime import datetime
+
+from . import BaseApi, BaseUrl, Region, Rank
+from . import schemas
 
 
 class Clan(BaseApi):
@@ -17,7 +20,9 @@ class Clan(BaseApi):
         """
 
         method = f"{self.region.value}/clan/{self.clan_id}/info"
-        return self._request(method)
+        response = self._request(method)
+
+        return schemas.ClanInfo(response)
 
     def __repr__(self):
         return f"<Clan> clan_id='{self.clan_id}' region='{self.region}'"
@@ -43,7 +48,12 @@ class UserClan(Clan):
         """
 
         method = f"{self.region.value}/clan/{self.clan_id}/members"
-        return self._request(method)
+        response = self._request(method)
+
+        return [
+            schemas.ClanMember(member)
+            for member in response
+        ]
 
     def __repr__(self):
         return f"<UserClan> clan_id='{self.clan_id}' region='{self.region}'"
