@@ -1,4 +1,5 @@
-from . import AppClan, Auction, BaseApi, BaseUrl, Region, UserClan
+from . import AppClan, Auction, BaseApi, BaseUrl, Region, UserClan, Rank
+from . import schemas
 
 
 class Client(BaseApi):
@@ -19,7 +20,12 @@ class Client(BaseApi):
         """
 
         method = "regions"
-        return self._request(method)
+        response = self._request(method)
+
+        return [
+            schemas.RegionInfo(region)
+            for region in response
+        ]
 
     def emission(self, region=Region.RU):
         """
@@ -30,7 +36,9 @@ class Client(BaseApi):
         """
 
         method = f"{region.value}/emission"
-        return self._request(method)
+        response = self._request(method)
+
+        return schemas.Emission(response)
 
     def clans(self, offset=0, limit=20, region=Region.RU):
         """
@@ -46,7 +54,9 @@ class Client(BaseApi):
 
         method = f"{region.value}/clans"
         params = {"offset": offset, "limit": limit}
-        return self._request(method, params)
+        response = self._request(method, params)
+
+        return schemas.Clans(response)
 
     def auction(self, item_id, region=Region.RU):
         """
@@ -95,7 +105,12 @@ class UserClient(Client):
         """
 
         method = f"{region.value}/characters"
-        return self._request(method)
+        response = self._request(method)
+
+        return [
+            schemas.Character(character)
+            for character in response
+        ]
 
     def friends(self, character: str, region=Region.RU):
         """
